
rm(list = setdiff(ls(),c("PFAD","print.T1","print.T2","id")))
options(stringsAsFactors = F)

if("reshape" %in% rownames(installed.packages()) == F) install.packages("reshape")
# if("miceadds" %in% rownames(installed.packages()) == F) install.packages("miceadds")
if("stringr" %in% rownames(installed.packages()) == F) install.packages("stringr")

library(reshape)
#library(miceadds)
library(stringr)

wd <- file.path(PFAD,paste0("Ergebnisse_",Sys.Date()))
if(!dir.exists(wd)) dir.create(wd)

id0 <- id

prep.dat <- function(dat, t){
  # Daten mergen
  
  # Gruppen-Mittelwert
    vs <- setdiff(names(dat),c("MZP","Item.Nr","Bereich","Itemtext"))
    if(length(vs) > 1){
      dat$M <- rowMeans(dat[,vs],na.rm=T)
      for(x in 1:4) 
        dat[,paste0("N",x)] <- rowSums(dat[,vs] == x,na.rm=T)
    } else if(length(vs)==1){
      dat$M <- dat[,vs]
      for(x in 1:4) 
        dat[,paste0("N",x)] <- 1*(dat[,vs] == x)
    }
    
  return(dat)
  
}

print.emu <- function(dat,id,t,mb,PFAD){
  
  items <- dat$Item.Nr[which(dat$Bereich %in% mb)]
  mbb <- dat$Bereich[match(items,dat$Item.Nr)]
  lt.items <- sapply(mb, function(x) sum(mbb == x))
  
  itext <- dat$Itemtext[match(items,dat$Item.Nr)]
  if(any(is.na(itext))){
    pp <- which(is.na(itext))
    itext[pp] <- dat.t$Itemtext[match(items[pp],dat.t$Item.Nr)]
  }
  
  # Ergebnisse von IDs
  if(id0 == "") id <- setdiff(names(dat),c("MZP","Item.Nr","Bereich","Itemtext",
                                             "M",paste0("N",1:4)))
  for(ii in 1:length(id)){
    
    pid <- id[ii]
    
    # Abbildung-Name
    pdf.name <- paste0("EMU-Skalen_",t,"__",pid,"__",time,".pdf")
    
    # Grafik speichern
    h <- floor(sum(lt.items)/2)
    pdf(file.path(wd,pdf.name),onefile = T,width = 10,height = h)
    
    # Abbilden
    pp <- match(items, dat$Item.Nr)
    nc <- setdiff(unique(rowSums(dat[pp,grep("^N[[:digit:]]",names(dat))])),NA)
    
    if(any(nc > 1)){
      layout(mat = matrix(1:(lt*2),ncol=2,byrow=T),
             widths = c(3,1),
             heights = lt.items + 1)
    } else layout(mat = matrix(c(1:lt,rep(0,lt)),ncol=2),
                  widths = c(3,1),heights = lt.items + 1)
    
    # Abgleich-Grafik
    for(b in mb){
      # b <- mb[1]
      
      items.b <- items[which(mbb == b)]
      text.b <- itext[match(items.b, items)]
      lt.b <- length(items.b)
      
      if(length(mb) == 1){
        cex.main <- cex <- cex.axis <- 0.6
        inset = c(0, -1/(lt.b+1))} else {
          cex.main <- cex <- cex.axis <- 0.8
          inset = c(0, -1/(lt.b+1))
        }
      
      # Mittelwert Grafik
      par(xpd=FALSE)
      par(mai = c(0.3,4,0.5,0.2))
      
      plot(x = rep(1:4,lt.b), 
           y = rep(lt.b:1,4), 
           ylim = c(0.5,lt.b+0.5),
           type="n",
           yaxt = "n",xaxt = "n",
           xlab = "",ylab="",cex = 0.5)
      
      axis(side = 3,at = seq(1,4,0.5),cex.axis = cex.axis,
           labels = c("stimme\nnicht zu",seq(1.5,3.5,0.5),"stimme\nzu"))
      par(xpd=T)
      mtext(text = paste(b,t),side = 2,line = 2,at = ceiling(lt.b+1),
            font = 2,
            cex = cex,las=1)
      
      # Items
      par(xpd=FALSE)
      text.b <- gsub(" $","",text.b)
      text.b1 <- strsplit(text.b,split = " ")
      text <- NULL
      for(i in 1:length(text.b1)){
        string <- text.b1[[i]]
        string <- str_c(string, collapse = " ")
        string <- gsub(" $","",string)
        string <- gsub("\\.$","",string)
        # max length of string <- 60
        num.chars <- nchar(string)
        if(num.chars > 60){
          # find last space before 60
          pp <- strsplit(substr(string,1,60),split = " ")[[1]]
          first <- str_c(pp[1:(length(pp)-1)],collapse=" ")
          last <- gsub(first,"",string)
          last <- gsub("^ ","",last)
          string <- paste0(first,"\n",last)
        }
        text[i] <- string
      }
      
      if(length(mb) == 1) cex.item = 0.6 else cex.item = 1
      axis(side = 2,at = c(lt.b:1),labels = text,line = 0,tick=F,las=2,
           cex.axis = cex.item)
      abline(v = seq(1,4,0.5),col="lightgrey")
      abline(h = c(1:lt.b),col="lightgrey",lty=2)
      if("M" %in% names(dat))
        points(x = dat$M[match(items.b,dat$Item.Nr)],
               y = lt.b:1,type="b",col="black",pch = 15,cex = 1.2)
      
      # Person PID
      points(x = dat[match(items.b,dat$Item.Nr),pid],
             y = lt.b:1,type="b",col="red",pch = 19,cex = 1.0)
      
      
      par(xpd=TRUE)
      legend(x=2.5,y = 0.25,bty = "n" ,horiz=T,cex = cex,xjust = 0.5,
             legend = c("Gruppenmittelwert",pid),
             pch=c(15,19),lty=2,col=c("black","red"))
      
      # Verteilung Antworte
      if(any(nc > 1)){
        par(xpd=FALSE)
        par(mai = c(0.3,0.5,0.5,0.2))
        mat1 <- dat[match(items.b[lt.b:1],dat$Item.Nr),
                    c("Item.Nr",paste0("N",1:4))]
        colnames(mat1)[-1] <- paste0("N",1:4)
        bp2 <- barplot(t(as.matrix(mat1[,-1])),beside = F,horiz=T,
                       xaxt="n",yaxt="n",
                       legend.text = T,border=F,col=c("lightpink","pink3","purple1","purple3"),
                       args.legend = list(x = "bottom", bty = "n", 
                                          inset=inset,
                                          horiz=T,
                                          cex = cex),
                       main = "Verteilung der Antworte",cex.main=0.8)
        y <- lab <- (as.matrix(mat1[,-1]))
        for(ii in 2:4) y[,ii] <- rowSums(y[,c(ii,ii-1)])
        y <- y - lab/2
        lab[lab == 0] <- NA
        text(y,bp2, labels=as.character(lab), cex=0.62)
        
        # Mittelwert
        M <- round(dat$M[match(items.b,dat$Item.Nr)],1)[lt.b:1]
        lab.M <- paste0("M = ",M)
        lab.M[lab.M == "M = NA"] <- ""
        axis(side = 2,at = seq(0.7,lt.b+0.1*lt.b,length.out = lt.b),
             labels = lab.M,cex.axis=cex.axis,
             tick = F,pos = 0,las=1)
      }
      
    }
    
    dev.off()
  }
  
}

print.zusatz <- function(dat, id, t,zb,PFAD){
  
  # Wenn eine  Skala mehr als 40 Items hat, dann trenne es in 3
  # Wenn eine Skala mehr als 20 Items hat, dann trenne es in 2
  # wenn mehrere Skalen weniger als 20 Items hat, 
  # dann Erg. von mehreren Skalen werden in einer Seite gedruckt
  # layout wird variabel erstellt.
  
  # Ergebnisse von IDs
  if(id0 == "") id <- setdiff(names(dat),c("MZP","Item.Nr","Bereich","Itemtext",
                                          "M",paste0("N",1:4)))
  for(ii in 1:length(id)){
    
    # ii <- 1
    pid <- id[ii]
    
    # Abbildung-Name
    pdf.name <- paste0("Zusatzbereich_",t,"__",pid,"__",time,".pdf")
    
    items <- dat$Item.Nr[which(dat$Bereich %in% zb)]
    mbb <- dat$Bereich[match(items,dat$Item.Nr)]
    lt.items <- sapply(zb, function(x) sum(mbb == x))
    
    # Neu verteilen anhand Itemuzahl pro Skala
    nitems <- list()
    # Anzahl Skalen mit Itemzahl >= x
    n41 <- sum(lt.items >= 41)
    if(n41 > 0){
      s41 <- names(lt.items)[lt.items >= 41]
      # in 3 teilen
      for(ss in s41){
        s.items <- dat$Item.Nr[which(dat$Bereich == ss)]
        trenn <- floor(length(s.items)/3)
        nitems[[paste0(ss," (Seite 1)")]] <- s.items[1:trenn]
        nitems[[paste0(ss," (Seite 2)")]] <- s.items[(trenn+1):(trenn*2)]
        nitems[[paste0(ss," (Seite 3)")]] <- s.items[(trenn*2+1):length(s.items)]
      }
    }
    n21 <- sum(lt.items >= 21 & lt.items <= 40)
    if(n21 > 0){
      s21 <- names(lt.items)[lt.items >= 21 & lt.items <= 40]
      # in 2 teilen
      for(ss in s21){
        # ss = s21[1]
        s.items <- dat$Item.Nr[which(dat$Bereich == ss)]
        trenn <- floor(length(s.items)/2)
        nitems[[paste0(ss," (Seite 1)")]] <- s.items[1:trenn]
        nitems[[paste0(ss," (Seite 2)")]] <- s.items[(trenn+1):length(s.items)]
      }
    }
    n20 <- sum(lt.items <= 20)
    if(n20 > 0){
      # if Itemzahl insgesamt < 30: alle in einer Seite
      # if Itemzahl insgesamt >= 30: alle in 2 Seiten
      s20 <- names(lt.items)[lt.items <= 20]
      if(sum(lt.items[s20] < 30)){
        s.items <- dat$Item.Nr[which(dat$Bereich %in% s20)]
        nitems[["Rest"]] <- s.items
      } else {
        lt.s20 <- lt.items[s20]
        X <- lt.s20 <- lt.s20[order(lt.s20,decreasing = T)]
        for(ll in 2:length(lt.s20)) X[ll] <- X[ll] + X[ll-1]
        trenn <- ceiling(sum(lt.items[s20])/2)
        pp <- 1*(X <= trenn)
        
        # Gruppe 1
        ss <- names(pp)[pp == 1]
        s.items <- dat$Item.Nr[which(dat$Bereich %in% ss)]
        nitems[["Gruppe 1"]] <- s.items
        
        # Gruppe 2
        ss <- names(pp)[pp == 0]
        s.items <- dat$Item.Nr[which(dat$Bereich %in% ss)]
        nitems[["Gruppe 2"]] <- s.items
      }
    }
    
    fu <- sapply(1:length(nitems),function(x) nitems[[x]][1])
    nitems <- nitems[order(fu)]
    
    # Sind alle Skalen und Items enthalten?
    if(!all(items %in% unlist(nitems))) stop("es fehlen Zusatzitems")
    
    # Grafik speichern
    lt.n <- sapply(1:length(nitems),function(x) length(nitems[[x]]))
    h = ceiling(max(lt.n) / 3) + 1
    
    pdf(file.path(wd,pdf.name),onefile = T,width=10, 
        height = h)
    
    # Pro Objekt in nitems eine Seite ausdrucken
    
    for(jj in 1:length(nitems)){
      # jj <- 1
      # Items
      items.jj <- nitems[[jj]]
      
      # Itemformulierung
      itext <- dat$Itemtext[match(items.jj,dat$Item.Nr)]
      if(any(is.na(itext))){
        pp <- which(is.na(itext))
        itext[pp] <- dat.t$Itemtext[match(items.jj[pp],dat.t$Item.Nr)]
      }
      if(any(is.na(itext))){
        pp <- which(is.na(itext))
        itext[pp] <- dat.t$Itemtext[match(items.jj[pp],dat.s$Item.Nr)]
      }
      
      # Skalen
      sk.jj <- dat$Bereich[match(items.jj,dat$Item.Nr)]
      lt.jj <- length(unique(sk.jj))
      
      # nur eine Skala
      if(lt.jj == 1){
        # Abbilden
        pp <- match(items.jj, dat$Item.Nr)
        nc <- setdiff(unique(rowSums(dat[pp,grep("^N[[:digit:]]",names(dat))])),NA)
        
        # Eine Seite, Eine Skala
        if(nc > 1){
          layout(mat = matrix(1:2,ncol=2,byrow=T),
                 widths = c(3,1),heights = length(items.jj) + 1, respect = F)
        } else layout(mat = matrix(c(1,0),ncol=2),
                      widths = c(3,1),heights = length(items.jj) + 1, respect = F)
        
        # Abgleich-Grafik
        
        b <- unique(sk.jj)
        items.b <- items.jj
        text.b <- itext[match(items.b, items.jj)]
        lt.b <- length(items.b)
        
        if(lt.b < 7){
          cex.main <- cex <- cex.axis <- 0.6
          inset = c(0, -(1/(lt.b+1)))
          
          cex.item = 0.7
          inset = c(0, -0.1)} else {
            cex.main <- cex <- cex.axis <- 0.8
            inset <- c(0, -(1/(lt.b+1)))
            cex.item = 0.9
          }
        
        # Mittelwert Grafik
        par(xpd=FALSE)
        par(mai = c(0.7,4,0.7,0.5))
        
        plot(x = rep(1:4,lt.b), 
             y = rep(lt.b:1,4), 
             ylim = c(0.5,lt.b+0.5),
             type="n",
             yaxt = "n",xaxt = "n",
             xlab = "",ylab="",cex = 0.5)
        axis(side = 3,at = seq(1,4,0.5),cex.axis = cex.axis,
             labels = c("stimme\nnicht zu",seq(1.5,3.5,0.5),"stimme\nzu"))
        par(xpd=T)
        mtext(text = paste(b,t),side = 2,line = 2,at = ceiling(lt.b+1),
              font = 2,
              cex = cex,las=1)
        
        # Items
        par(xpd=FALSE)
        text.b <- gsub(" $","",text.b)
        text.b1 <- strsplit(text.b,split = " ")
        text <- NULL
        for(i in 1:length(text.b1)){
          string <- text.b1[[i]]
          string <- str_c(string, collapse = " ")
          string <- gsub(" $","",string)
          string <- gsub("\\.$","",string)
          # max length of string <- 60
          num.chars <- nchar(string)
          if(num.chars > 60){
            # find last space before 60
            pp <- strsplit(substr(string,1,60),split = " ")[[1]]
            first <- str_c(pp[1:(length(pp)-1)],collapse=" ")
            last <- gsub(first,"",string)
            last <- gsub("^ ","",last)
            string <- paste0(first,"\n",last)
          }
          text[i] <- string
        }
        
        axis(side = 2,at = c(lt.b:1),labels = text,line = 0,tick=F,las=2,
             cex.axis = cex.item)
        abline(v = seq(1,4,0.5),col="lightgrey")
        abline(h = c(1:lt.b),col="lightgrey",lty=2)
        if("M" %in% names(dat))
          points(x = dat$M[match(items.b,dat$Item.Nr)],
                 y = lt.b:1,type="b",col="black",pch = 15,cex = 1.2)
        
        points(x = dat[match(items.b,dat$Item.Nr),pid],
               y = lt.b:1,type="b",col="red",pch = 19,cex = 1.0)
        
        par(xpd=TRUE)
        if(lt.b < 7) y = 0.1 else y = -0.2
        legend(x=2.5,y = y,bty = "n" ,horiz=T,cex = cex,xjust = 0.5,
               legend = c("Gruppenmittelwert",pid),
               pch=c(15,19),lty=2,col=c("black","red"))
        
        # Verteilung Antworte
        if(nc > 1){
          par(xpd=FALSE)
          par(mai = c(0.7,0.5,0.7,0.5))
          
          mat1 <- dat[match(items.b[lt.b:1],dat$Item.Nr),
                      c("Item.Nr",paste0("N",1:4))]
          colnames(mat1)[-1] <- paste0("N",1:4)
          bp1 <- barplot(t(as.matrix(mat1[,-1])),beside = F,horiz=T,
                         xaxt="n",yaxt="n",
                         legend.text = T,
                         border=F,col=c("yellow","orange","darkorange","orange3"),
                         args.legend = list(x = "bottom", bty = "n", 
                                            inset=inset,
                                            horiz=T,
                                            cex = cex-0.1),
                         main = "Verteilung der Antworte",cex.main=cex.main)
          
          y <- lab <- (as.matrix(mat1[,-1]))
          for(ii in 2:4) y[,ii] <- rowSums(y[,c(ii,ii-1)])
          y <- y - lab/2
          lab[lab == 0] <- NA
          text(y,bp1, labels=as.character(lab), cex=0.62)
          
          # Mittelwert:
          M <- round(dat$M[match(items.b,dat$Item.Nr)],1)[lt.b:1]
          lab.M <- paste0("M = ",M)
          lab.M[lab.M == "M = NA"] <- ""
          axis(side = 2,at = seq(0.7,lt.b+0.2*(lt.b-2),length.out = lt.b),
               labels = lab.M,cex.axis=cex.axis,
               tick = F,pos = 0,las=1)
        }
        
      }
      
      # Mehrere Skalen
      if(lt.jj > 1){
        # Abbilden
        pp <- match(items.jj, dat$Item.Nr)
        nc <- setdiff(unique(rowSums(dat[pp,grep("^N[[:digit:]]",names(dat))])),NA)
        
        
        # Anzahl Items
        jb <- unique(sk.jj)
        lt.jb <- sapply(jb, function(x) sum(sk.jj == x))
        
        # Eine Seite, Mehrere Skala
        if(any(nc > 1)){
          layout(mat = matrix(1:(lt.jj*2),ncol=2,byrow=T),
                 widths = c(3,1),heights = lt.jb + 1)
        } else layout(mat = matrix(c(1,lt.jj,rep(0,lt.jj)),ncol=2),
                      widths = c(3,1),heights = lt.jb + 1)
        
        
        
        # Abgleich-Grafik
        for(b in jb){
          # b <- jb[1]
          items.b <- items.jj[sk.jj == b]
          text.b <- itext[match(items.b, items.jj)]
          lt.b <- length(items.b)
          
          # Mittelwert Grafik
          par(xpd=FALSE)
          par(mai = c(0.5,4,0.7,0.5))
          
          if(lt.b < 7){
            cex.main <- cex <- cex.axis <- 0.6
            inset = c(0, -(1/(lt.b+1)))
            
            cex.item = 0.7
            inset = c(0, -0.1)} else {
              cex.main <- cex <- cex.axis <- 0.8
              inset <- c(0, -(1/(lt.b+1)))
              cex.item = 0.9
            }
          
          plot(x = rep(1:4,lt.b), 
               y = rep(lt.b:1,4), 
               ylim = c(0.5,lt.b+0.5),
               type="n",
               yaxt = "n",xaxt = "n",
               xlab = "",ylab="",cex = 0.5)
          axis(side = 3,at = seq(1,4,0.5),cex.axis = 0.8,
               labels = c("stimme\nnicht zu",seq(1.5,3.5,0.5),"stimme\nzu"))
          par(xpd=T)
          mtext(text = paste(b,t),side = 2,line = 2,at = ceiling(lt.b+1),
                font = 2,
                cex = 0.7,las=1)
          
          # Items
          par(xpd=FALSE)
          text.b <- gsub(" $","",text.b)
          text.b1 <- strsplit(text.b,split = " ")
          text <- NULL
          for(i in 1:length(text.b1)){
            string <- text.b1[[i]]
            string <- str_c(string, collapse = " ")
            string <- gsub(" $","",string)
            string <- gsub("\\.$","",string)
            # max length of string <- 60
            num.chars <- nchar(string)
            if(num.chars > 60){
              # find last space before 60
              pp <- strsplit(substr(string,1,60),split = " ")[[1]]
              first <- str_c(pp[1:(length(pp)-1)],collapse=" ")
              last <- gsub(first,"",string)
              last <- gsub("^ ","",last)
              string <- paste0(first,"\n",last)
            }
            text[i] <- string
          }
          
          axis(side = 2,at = c(lt.b:1),labels = text,line = 0,tick=F,las=2,
               cex.axis = 1)
          abline(v = seq(1,4,0.5),col="lightgrey")
          abline(h = c(1:lt.b),col="lightgrey",lty=2)
          if("M" %in% names(dat))
            points(x = dat$M[match(items.b,dat$Item.Nr)],
                   y = lt.b:1,type="b",col="black",pch = 15,cex = 1.2)
          
          points(x = dat[match(items.b,dat$Item.Nr),pid],
                 y = lt.b:1,type="b",col="red",pch = 19,cex = 1.0)
          
          par(xpd=TRUE)
          legend(x=2.5,y = 0.25,bty = "n" ,horiz=T,cex = 0.9,xjust = 0.5,
                 legend = c("Gruppenmittelwert",pid),
                 pch=c(15,19),lty=2,col=c("black","red"))
          
          # Verteilung Schülerantworte
          if(any(nc > 1)){
            par(xpd=FALSE)
            par(mai = c(0.5,0.5,0.7,0.5))
            
            mat1 <- dat[match(items.b[lt.b:1],dat$Item.Nr),
                        c("Item.Nr",paste0("N",1:4))]
            colnames(mat1)[-1] <- paste0("N",1:4)
            bp1 <- barplot(t(as.matrix(mat1[,-1])),beside = F,horiz=T,
                           xaxt="n",yaxt="n",
                           legend.text = T,
                           border=F,col=c("yellow","orange","darkorange","orange3"),
                           args.legend = list(x = "bottom", bty = "n", 
                                              inset=inset,
                                              horiz=T,
                                              cex = 0.7),
                           main = "Verteilung der Antworte",cex.main=0.8)
            
            y <- lab <- (as.matrix(mat1[,-1]))
            for(ii in 2:4) y[,ii] <- rowSums(y[,c(ii,ii-1)])
            y <- y - lab/2
            lab[lab == 0] <- NA
            text(y,bp1, labels=as.character(lab), cex=0.62)
            
            # Mittelwert:
            M <- round(dat$M[match(items.b,dat$Item.Nr)],1)[lt.b:1]
            lab.M <- paste0("M = ",M)
            lab.M[lab.M == "M = NA"] <- ""
            axis(side = 2,at = seq(0.7,lt.b+0.2*(lt.b-2),length.out = lt.b),
                 labels = lab.M,cex.axis=0.8,
                 tick = F,pos = 0,las=1)
          }
          
        }
        
        
        
      }
      
    }
    
    dev.off()
    
  }
  
  
  
}

bereich <- c("KLASSENMANAGEMENT",
             "LERNFÖRDERLICHES KLIMA UND MOTIVIERUNG",
             "KLARHEIT UND STRUKTURIERUNG",
             "AKTIVIERUNG UND FÖRDERUNG",
             "BILANZ")

# time <- Sys.time()
# time <- gsub(" ","_",time)
# time <- gsub(":","",time)
time <- Sys.Date()

# Daten einlesen

{
  # Daten
  lf <- list.files(PFAD,"Gruppendaten(.)*.csv",full.names=T)
  if(length(lf) == 0) stop("Keine csv-Datensätze wurden im Ordner PFAD gefunden")
  
  dat.t1 <- dat.t2 <- NULL
  
  # T1
  if(length(grep("T1",lf))>0){
    pp <- grep("T1",lf)
    lf1 <- max(lf[pp])
    dat.t1 <- read.csv2(lf1,encoding = "utf8")
    dat.t1$Bereich <- toupper(dat.t1$Bereich)
    
    # alle leere Spalten löschen
    if(any(colMeans(is.na(dat.t1)) == 1)){
      del <- which(colMeans(is.na(dat.t1)) == 1)
      if(length(del)>0) dat.t1 <- dat.t1[,-del]
      vs <- setdiff(names(dat.t1),c("MZP","Item.Nr","Bereich","Itemtext"))
      if(length(vs) == 0) dat.t1 <- NULL
    }
    
    # alle leere Zeilen löschen
    cn <- setdiff(names(dat.t1),c("MZP","Item.Nr","Bereich","Itemtext"))
    if(length(cn)==1){
      del <- which(is.na(dat.t1[,cn]))
      if(length(del)>0) dat.t1 <- dat.t1[-del,]
      nn <- nrow(dat.t1)
      if(nn == 0) dat.t1 <- NULL
    } else if(any(rowMeans(is.na(dat.t1[,cn])) == 1)){
      del <- which(rowMeans(is.na(dat.t1[,cn])) == 1)
      if(length(del)>0) dat.t1 <- dat.t1[-del,]
      nn <- nrow(dat.t1)
      if(nn == 0) dat.t1 <- NULL
    }
    
    # Check Werte
    vs <- setdiff(names(dat.t1),c("MZP","Item.Nr","Bereich","Itemtext"))
    items <- dat.t1$Item.Nr
    
    if(!all(as.numeric(names(table(unlist(dat.t1[,vs])))) %in% c(1:4)))
      stop("Daten T1: Es gibt ungültige Werte (1 bis 4)")

  }
  
  # T2
  if(length(grep("T2",lf))>0){
    pp <- grep("T2",lf)
    lf1 <- max(lf[pp])
    dat.t2 <- read.csv2(lf1,encoding = "utf8")
    dat.t2$Bereich <- toupper(dat.t2$Bereich)
    
    # alle leere Spalten löschen
    if(any(colMeans(is.na(dat.t2)) == 1)){
      del <- which(colMeans(is.na(dat.t2)) == 1)
      if(length(del)>0) dat.t2 <- dat.t2[,-del]
      vs <- setdiff(names(dat.t2),c("MZP","Item.Nr","Bereich","Itemtext"))
      if(length(vs) == 0) dat.t2 <- NULL
    }
    
    # alle leere Zeilen löschen
    cn <- setdiff(names(dat.t2),c("MZP","Item.Nr","Bereich","Itemtext"))
    if(length(cn)==1){
      del <- which(is.na(dat.t2[,cn]))
      if(length(del)>0) dat.t2 <- dat.t2[-del,]
      nn <- nrow(dat.t2)
      if(nn == 0) dat.t2 <- NULL
    } else if(any(rowMeans(is.na(dat.t2[,cn])) == 1)){
      del <- which(rowMeans(is.na(dat.t2[,cn])) == 1)
      if(length(del)>0) dat.t2 <- dat.t2[-del,]
      nn <- nrow(dat.t2)
      if(nn == 0) dat.t2 <- NULL
    }
    
    # Check Werte
    vs <- setdiff(names(dat.t2),c("MZP","Item.Nr","Bereich","Itemtext"))
    items <- dat.t2$Item.Nr
    
    if(!all(as.numeric(names(table(unlist(dat.t2[,vs])))) %in% c(1:4)))
      stop("Daten T2: Es gibt ungültige Werte (1 bis 4)")
    
  }
  
}

#-----------------------------------------------------------------------------##
# Ergebnisse T1

if(print.T1 == 1){
  
  # Daten mergen
  dat1 <- prep.dat(dat = dat.t1,t = "T1")
  if(id != "" & !(id %in% names(dat1))){
    stop("Bitte geben Sie eine korrekte ID um Ergebnisse T1 auszudrucken")
  }
    
  
  # Abbildungen
  
  {
    
    # EMU-Items
    items <- dat1$Item.Nr
    e.items <- grep("^I",items,value=T)
    z.items <- grep("^ZI",items,value=T)
    
    # Bereiche
    bb <- unique(dat1$Bereich)
    mb <- intersect(bb,bereich)
    zb <- setdiff(bb,bereich)
    
    
    #--------------------------------------------------------
    # T1 - EMU Abbildungen
    
    lt <- length(mb)
    
    if(lt > 0){
      print.emu(dat = dat1, id = id, t = "T1",mb = mb,PFAD = PFAD)
    }
    
    
    #--------------------------------------------------------
    # T1 - Zusatzskalen
    
    lt <- length(zb)
    
    if(lt > 0){
      print.zusatz(dat = dat1, id = id, t = "T1",zb = zb, PFAD = PFAD)
    }
    
    
  }
  
  print("Ergebnisse T1 wurden ausgedruckt und gespeichert")

}

#-----------------------------------------------------------------------------##
# Ergebnisse T2

if(print.T2 == 1){
  
  # Daten mergen
  dat2 <- prep.dat(dat = dat.t2,t = "T2")
  if(id != "" & !(id %in% names(dat2))){
    stop("Bitte geben Sie eine korrekte ID um Ergebnisse T2 auszudrucken")
  }
  
  
  # Abbildungen
  
  {
    
    # EMU-Items
    items <- dat2$Item.Nr
    e.items <- grep("^I",items,value=T)
    z.items <- grep("^ZI",items,value=T)
    
    # Bereiche
    bb <- unique(dat2$Bereich)
    mb <- intersect(bb,bereich)
    zb <- setdiff(bb,bereich)
    
    
    #--------------------------------------------------------
    # T2 - EMU Abbildungen
    
    lt <- length(mb)
    
    if(lt > 0){
      print.emu(dat = dat2, id = id, t = "T2",mb = mb,PFAD = PFAD)
    }
    
    
    #--------------------------------------------------------
    # T2 - Zusatzskalen
    
    lt <- length(zb)
    
    if(lt > 0){
      print.zusatz(dat = dat2, id = id, t = "T2",zb = zb, PFAD = PFAD)
    }
    
    
  }
  
  print("Ergebnisse T2 wurden ausgedruckt und gespeichert")
  
}


#-----------------------------------------------------------------------------##
# Ergebnisse T1, T2
if(print.T1 == 1 & print.T2 == 1){
  # EMU-Items
  
  # Bereiche
  bb <- union(unique(dat1$Bereich), unique(dat2$Bereich))
  
  #--------------------------------------------------------
  # Beide MZP: EMU-Skalen
  
  mb <- intersect(bb,bereich)
  lt <- length(mb)
  if(lt > 0){
    
    items <- dat1$Item.Nr[which(dat1$Bereich %in% mb)]
    items2 <- dat2$Item.Nr[which(dat2$Bereich %in% mb)]
    items <- union(items, items2)
    
    mbb <- dat1$Bereich[match(items,dat1$Item.Nr)]
    pp <- which(is.na(mbb))
    if(length(pp)>0){
      mbb[pp] <- dat2$Bereich[match(items[pp],dat2$Item.Nr)]
    }
    lt.items <- sapply(mb, function(x) sum(mbb == x))
    
    itext <- dat1$Itemtext[match(items,dat1$Item.Nr)]
    pp <- which(is.na(itext))
    if(length(pp)>0){
      itext[pp] <- dat2$Itemtext[match(items[pp],dat2$Item.Nr)]
    }
    if(any(is.na(itext))){
      pp <- which(is.na(itext))
      itext[pp] <- dat.t1$Itemtext[match(items[pp],dat.t1$Item.Nr)]
    }
    if(any(is.na(itext))){
      pp <- which(is.na(itext))
      itext[pp] <- dat.t2$Itemtext[match(items[pp],dat.t2$Item.Nr)]
    }
    
    if(id0 == ""){
      id1 <- setdiff(names(dat1),c("MZP","Item.Nr","Bereich","Itemtext",
                                            "M",paste0("N",1:4)))
      id2 <- setdiff(names(dat2),c("MZP","Item.Nr","Bereich","Itemtext",
                                   "M",paste0("N",1:4)))
      id <- sort(union(id1, id2))
    }
      
    for(ii in 1:length(id)){
      # ii <- 1
      
      pid <- id[ii]
      
      # Abbildung-Name
      pdf.name <- paste0("EMU-Skalen_beider_Messungen__",pid,"__",time,".pdf")
      
      # Grafik speichern
      h <- floor(sum(lt.items)/2)
      pdf(file.path(wd,pdf.name),onefile = T,width = 10,height = h)
      
      # Abbilden
      
      layout(mat = matrix(1:(lt*2),ncol=2,byrow=T),
               widths = c(2,0.9),
               heights = lt.items + 1)
      
      
      # Abbildung
      for(b in mb){
        # b <- mb[1]
        
        items.b <- items[which(mbb == b)]
        text.b <- itext[match(items.b, items)]
        lt.b <- length(items.b)
        
        # Gruppen-MW
        par(xpd=FALSE)
        par(mai = c(0.3,4,0.5,0.2))
        
        plot(x = rep(1:4,lt.b), 
             y = rep(lt.b:1,4), 
             ylim = c(0.5,lt.b+0.5),
             type="n",
             yaxt = "n",xaxt = "n",
             xlab = "",ylab="",cex = 0.5)
        axis(side = 3,at = seq(1,4,0.5),cex.axis = 0.8,
             labels = c("stimme\nnicht zu",seq(1.5,3.5,0.5),"stimme\nzu"))
        par(xpd=T)
        mtext(text = paste0(b),side = 2,line = 2,at = ceiling(lt.b+1),
              font = 2,
              cex = 0.7,las=1)
        
        # Items
        par(xpd=FALSE)
        text.b <- gsub(" $","",text.b)
        text.b1 <- strsplit(text.b,split = " ")
        text <- NULL
        for(i in 1:length(text.b1)){
          string <- text.b1[[i]]
          string <- str_c(string, collapse = " ")
          string <- gsub(" $","",string)
          string <- gsub("\\.$","",string)
          # max length of string <- 60
          num.chars <- nchar(string)
          if(num.chars > 60){
            # find last space before 60
            pp <- strsplit(substr(string,1,60),split = " ")[[1]]
            first <- str_c(pp[1:(length(pp)-1)],collapse=" ")
            last <- gsub(first,"",string)
            last <- gsub("^ ","",last)
            string <- paste0(first,"\n",last)
          }
          text[i] <- string
        }
        
        axis(side = 2,at = c(lt.b:1),labels = text,line = 0,tick=F,las=2,
             cex.axis = 1)
        abline(v = seq(1,4,0.5),col="lightgrey")
        abline(h = c(1:lt.b),col="lightgrey",lty=2)
        
        points(x = dat1$M[match(items.b,dat1$Item.Nr)],
                 y = lt.b:1,type="b",col="lightblue",pch = 15,cex = 1.2)
        points(x = dat2$M[match(items.b,dat2$Item.Nr)],
                 y = lt.b:1,type="b",col="blue4",pch = 18,cex = 1)
        par(xpd=TRUE)
        legend(x=2.5,y = 0.25,bty = "n" ,horiz=T,cex = 0.9,xjust = 0.5,
               legend = c("Gruppen-MW T1","Gruppen-MW T2"),
               pch=c(15,18),lty=2,col=c("lightblue","blue4"))
        
        # PID
        par(xpd=FALSE)
        par(mai = c(0.3,0.1,0.5,0.2))
        
        plot(x = rep(1:4,lt.b), 
             y = rep(lt.b:1,4), 
             ylim = c(0.5,lt.b+0.5),
             type="n",
             yaxt = "n",xaxt = "n",
             xlab = "",ylab="",cex = 0.5)
        axis(side = 3,at = seq(1,4,0.5),cex.axis = 0.8,
             labels = c("stimme\nnicht zu",seq(1.5,3.5,0.5),"stimme\nzu"))
        
        abline(v = seq(1,4,0.5),col="lightgrey")
        abline(h = c(1:lt.b),col="lightgrey",lty=2)
        
        if(pid %in% names(dat1))
          points(x = dat1[match(items.b,dat1$Item.Nr),pid],
                 y = lt.b:1,type="b",col="orange",pch = 15,cex = 1.2)
        if(pid %in% names(dat2))
          points(x = dat2[match(items.b,dat2$Item.Nr),pid],
                 y = lt.b:1,type="b",col="darkred",pch = 18,cex = 1)
        par(xpd=TRUE)
        legend(x=2.5,y = 0.25,bty = "n" ,horiz=T,cex = 0.9,xjust = 0.5,
               legend = paste0(pid,c(" T1"," T2")),
               pch=c(15,18),lty=2,col=c("orange","darkred"))

      }
      
      dev.off()
    }
    
  }
  
  
  #--------------------------------------------------------
  # Zusatzskalen
  
  zb <- setdiff(bb,bereich)
  lt <- length(zb)
  
  if(lt > 0){
    
    dat1a <- dat1[,-match("MZP",names(dat1))]
    dat2a <- dat2[,-match("MZP",names(dat2))]
    names(dat1a)[-c(1:3)] <- paste0("T1_",names(dat1a)[-c(1:3)])
    names(dat2a)[-c(1:3)] <- paste0("T2_",names(dat2a)[-c(1:3)])
    dat <- merge(dat1a, dat2a,all=T)
    
    # Nur Zusatzsitem
    dat <- dat[grep("ZI",dat$Item.Nr),]
    
    dat$lnr <- as.numeric(gsub("ZI","",dat$Item.Nr))
    dat <- dat[order(dat$lnr),]
    
    if(anyDuplicated(dat$Item.Nr)) 
      stop("Bitte Bereichnamen und Item.Nr unter Zusatzbereich in beiden Messungen identisch vergeben.",
           "\nAchten Sie bitte auch die Sonderzeichen inkl. Punkt, Kommas")
    
    
    # Wenn eine  Skala mehr als 40 Items hat, dann trenne es in 3
    # Wenn eine Skala mehr als 20 Items hat, dann trenne es in 2
    # wenn mehrere Skalen weniger als 20 Items hat, 
    # dann Erg. von mehreren Skalen werden in einer Seite gedruckt
    # layout wird variabel erstellt.
    
    if(id0 == ""){
      id1 <- setdiff(names(dat1),c("MZP","Item.Nr","Bereich","Itemtext",
                                   "M",paste0("N",1:4)))
      id2 <- setdiff(names(dat2),c("MZP","Item.Nr","Bereich","Itemtext",
                                   "M",paste0("N",1:4)))
      id <- sort(union(id1, id2))
    }
    
    
    for(ii in 1:length(id)){
      # ii <- 1
      pid <- id[ii]
      
      # Abbildung-Name
      pdf.name <- paste0("Zusatzbereich_beider_Messungen__",pid,"__",time,".pdf")
      
      items <- dat$Item.Nr[which(dat$Bereich %in% zb)]
      mbb <- dat$Bereich[match(items,dat$Item.Nr)]
      lt.items <- sapply(zb, function(x) sum(mbb == x))
      
      # Neu verteilen anhand Itemuzahl pro Skala
      nitems <- list()
      # Anzahl Skalen mit Itemzahl >= x
      n41 <- sum(lt.items >= 41)
      if(n41 > 0){
        s41 <- names(lt.items)[lt.items >= 41]
        # in 3 teilen
        for(ss in s41){
          s.items <- dat$Item.Nr[which(dat$Bereich == ss)]
          trenn <- floor(length(s.items)/3)
          nitems[[paste0(ss," (Seite 1)")]] <- s.items[1:trenn]
          nitems[[paste0(ss," (Seite 2)")]] <- s.items[(trenn+1):(trenn*2)]
          nitems[[paste0(ss," (Seite 3)")]] <- s.items[(trenn*2+1):length(s.items)]
        }
      }
      n21 <- sum(lt.items >= 21 & lt.items <= 40)
      if(n21 > 0){
        s21 <- names(lt.items)[lt.items >= 21 & lt.items <= 40]
        # in 2 teilen
        for(ss in s21){
          # ss = s21[1]
          s.items <- dat$Item.Nr[which(dat$Bereich == ss)]
          trenn <- floor(length(s.items)/2)
          nitems[[paste0(ss," (Seite 1)")]] <- s.items[1:trenn]
          nitems[[paste0(ss," (Seite 2)")]] <- s.items[(trenn+1):length(s.items)]
        }
      }
      n20 <- sum(lt.items <= 20)
      if(n20 > 0){
        # if Itemzahl insgesamt < 30: alle in einer Seite
        # if Itemzahl insgesamt >= 30: alle in 2 Seiten
        s20 <- names(lt.items)[lt.items <= 20]
        if(sum(lt.items[s20] < 30)){
          s.items <- dat$Item.Nr[which(dat$Bereich %in% s20)]
          nitems[["Rest"]] <- s.items
        } else {
          lt.s20 <- lt.items[s20]
          X <- lt.s20 <- lt.s20[order(lt.s20,decreasing = T)]
          for(ll in 2:length(lt.s20)) X[ll] <- X[ll] + X[ll-1]
          trenn <- ceiling(sum(lt.items[s20])/2)
          pp <- 1*(X <= trenn)
          
          # Gruppe 1
          ss <- names(pp)[pp == 1]
          s.items <- dat$Item.Nr[which(dat$Bereich %in% ss)]
          nitems[["Gruppe 1"]] <- s.items
          
          # Gruppe 2
          ss <- names(pp)[pp == 0]
          s.items <- dat$Item.Nr[which(dat$Bereich %in% ss)]
          nitems[["Gruppe 2"]] <- s.items
        }
      }
      
      # Sind alle Skalen und Items enthalten?
      if(!all(items %in% unlist(nitems))) stop("es fehlen Zusatzitems")
      
      fu <- sapply(1:length(nitems),function(x) nitems[[x]][1])
      nitems <- nitems[order(fu)]
      
      # Grafik speichern
      lt.n <- sapply(1:length(nitems),function(x) length(nitems[[x]]))
      h <- ceiling(max(lt.n)/2) + 1
      
      pdf(file.path(wd,pdf.name),onefile = T,width=10, 
          height = h)
      
      # Pro Objekt in nitems eine Seite ausdrucken
      
      for(jj in 1:length(nitems)){
        # jj <- 1
        # Items
        items.jj <- nitems[[jj]]
        
        # Itemformulierung
        itext <- dat$Itemtext[match(items.jj,dat$Item.Nr)]
        
        # Skalen
        sk.jj <- dat$Bereich[match(items.jj,dat$Item.Nr)]
        lt.jj <- length(unique(sk.jj))
        
        # nur eine Skala
        if(lt.jj == 1){
          # Abbilden
          
          items.b <- items.jj
          text.b <- itext[match(items.b, items.jj)]
          lt.b <- length(items.b)
          b <- unique(sk.jj)
          
          # Eine Seite, ine
          layout(mat = matrix(1:2,ncol=2,byrow=T),
                 widths = c(2,0.9),heights = lt.b + 1)
          
          # Gruppen-MW
          par(xpd=FALSE)
          par(mai = c(0.5,4,0.7,0.2))
          
          plot(x = rep(1:4,lt.b), 
               y = rep(lt.b:1,4), 
               ylim = c(0.5,lt.b+0.5),
               type="n",
               yaxt = "n",xaxt = "n",
               xlab = "",ylab="",cex = 0.5)
          axis(side = 3,at = seq(1,4,0.5),cex.axis = 0.8,
               labels = c("stimme\nnicht zu",seq(1.5,3.5,0.5),"stimme\nzu"))
          par(xpd=T)
          mtext(text = paste0(b),side = 2,line = 2,at = ceiling(lt.b+1),
                font = 2,
                cex = 0.7,las=1)
          
          # Items
          par(xpd=FALSE)
          text.b <- gsub(" $","",text.b)
          text.b1 <- strsplit(text.b,split = " ")
          text <- NULL
          for(i in 1:length(text.b1)){
            string <- text.b1[[i]]
            string <- str_c(string, collapse = " ")
            string <- gsub(" $","",string)
            string <- gsub("\\.$","",string)
            # max length of string <- 60
            num.chars <- nchar(string)
            if(num.chars > 60){
              # find last space before 60
              pp <- strsplit(substr(string,1,60),split = " ")[[1]]
              first <- str_c(pp[1:(length(pp)-1)],collapse=" ")
              last <- gsub(first,"",string)
              last <- gsub("^ ","",last)
              string <- paste0(first,"\n",last)
            }
            text[i] <- string
          }
          
          axis(side = 2,at = c(lt.b:1),labels = text,line = 0,tick=F,las=2,
               cex.axis = 1)
          abline(v = seq(1,4,0.5),col="lightgrey")
          abline(h = c(1:lt.b),col="lightgrey",lty=2)
          
          points(x = dat1$M[match(items.b,dat1$Item.Nr)],
                   y = lt.b:1,type="b",col="lightblue",pch = 15,cex = 1.2)
          points(x = dat2$M[match(items.b,dat2$Item.Nr)],
                   y = lt.b:1,type="b",col="blue4",pch = 18,cex = 1)
          par(xpd=TRUE)
          legend(x=2.5,y = -0.2,bty = "n" ,horiz=T,cex = 0.9,xjust = 0.5,
                 legend = c("Gruppen-MW T1","Gruppen-MW T2"),
                 pch=c(15,18),lty=2,col=c("lightblue","blue4"))
          
          # PID
          par(xpd=FALSE)
          par(mai = c(0.5,0.1,0.7,0.2))
          
          plot(x = rep(1:4,lt.b), 
               y = rep(lt.b:1,4), 
               ylim = c(0.5,lt.b+0.5),
               type="n",
               yaxt = "n",xaxt = "n",
               xlab = "",ylab="",cex = 0.5)
          axis(side = 3,at = seq(1,4,0.5),cex.axis = 0.8,
               labels = c("stimme\nnicht zu",seq(1.5,3.5,0.5),"stimme\nzu"))
          
          abline(v = seq(1,4,0.5),col="lightgrey")
          abline(h = c(1:lt.b),col="lightgrey",lty=2)
          
          if(pid %in% names(dat1))
          points(x = dat1[match(items.b,dat1$Item.Nr),pid],
                   y = lt.b:1,type="b",col="orange",pch = 15,cex = 1.2)
          if(pid %in% names(dat2))
            points(x = dat2[match(items.b,dat2$Item.Nr),pid],
                   y = lt.b:1,type="b",col="darkred",pch = 18,cex = 1)
          par(xpd=TRUE)
          legend(x=2.5,y = -0.2,bty = "n" ,horiz=T,cex = 0.9,xjust = 0.5,
                 legend = paste0(pid,c(" T1"," T2")),
                 pch=c(15,18),lty=2,col=c("orange","darkred"))
          
        }
        
        # Mehrere Skalen
        if(lt.jj > 1){
          # Abbilden
          
          # Anzahl Items
          jb <- unique(sk.jj)
          lt.jb <- sapply(jb, function(x) sum(sk.jj == x))
          
          # Eine Seite, Mehrere Skala
          layout(mat = matrix(1:(lt.jj*2),ncol=2,byrow=T),
                 widths = c(2,0.9),heights = lt.jb + 1)
          
          # Abgleich-Grafik
          for(b in jb){
            # b <- jb[1]
            items.b <- items.jj[sk.jj == b]
            text.b <- itext[match(items.b, items.jj)]
            lt.b <- length(items.b)
            
            # Gruppen
            par(xpd=FALSE)
            par(mai = c(0.3,4,0.7,0.2))
            
            plot(x = rep(1:4,lt.b), 
                 y = rep(lt.b:1,4), 
                 ylim = c(0.5,lt.b+0.5),
                 type="n",
                 yaxt = "n",xaxt = "n",
                 xlab = "",ylab="",cex = 0.5)
            axis(side = 3,at = seq(1,4,0.5),cex.axis = 0.8,
                 labels = c("stimme\nnicht zu",seq(1.5,3.5,0.5),"stimme\nzu"))
            par(xpd=T)
            mtext(text = paste0(b),side = 2,line = 2,at = ceiling(lt.b+1),
                  font = 2,
                  cex = 0.7,las=1)
            
            # Items
            par(xpd=FALSE)
            text.b <- gsub(" $","",text.b)
            text.b1 <- strsplit(text.b,split = " ")
            text <- NULL
            for(i in 1:length(text.b1)){
              string <- text.b1[[i]]
              string <- str_c(string, collapse = " ")
              string <- gsub(" $","",string)
              string <- gsub("\\.$","",string)
              # max length of string <- 60
              num.chars <- nchar(string)
              if(num.chars > 60){
                # find last space before 60
                pp <- strsplit(substr(string,1,60),split = " ")[[1]]
                first <- str_c(pp[1:(length(pp)-1)],collapse=" ")
                last <- gsub(first,"",string)
                last <- gsub("^ ","",last)
                string <- paste0(first,"\n",last)
              }
              text[i] <- string
            }
            
            axis(side = 2,at = c(lt.b:1),labels = text,line = 0,tick=F,las=2,
                 cex.axis = 1)
            abline(v = seq(1,4,0.5),col="lightgrey")
            abline(h = c(1:lt.b),col="lightgrey",lty=2)
            
            points(x = dat1$M[match(items.b,dat1$Item.Nr)],
                     y = lt.b:1,type="b",col="lightblue",pch = 15,cex = 1.2)
            points(x = dat2$M[match(items.b,dat2$Item.Nr)],
                     y = lt.b:1,type="b",col="blue4",pch = 18,cex = 1)
            par(xpd=TRUE)
            legend(x=2.5,y = 0.25,bty = "n" ,horiz=T,cex = 0.9,xjust = 0.5,
                   legend = c("Gruppen-MW T1","Gruppen-MW T2"),
                   pch=c(15,18),lty=2,col=c("lightblue","blue4"))
            
            # PID
            par(xpd=FALSE)
            par(mai = c(0.3,0.1,0.7,0.2))
            
            plot(x = rep(1:4,lt.b), 
                 y = rep(lt.b:1,4), 
                 ylim = c(0.5,lt.b+0.5),
                 type="n",
                 yaxt = "n",xaxt = "n",
                 xlab = "",ylab="",cex = 0.5)
            axis(side = 3,at = seq(1,4,0.5),cex.axis = 0.8,
                 labels = c("stimme\nnicht zu",seq(1.5,3.5,0.5),"stimme\nzu"))
            
            abline(v = seq(1,4,0.5),col="lightgrey")
            abline(h = c(1:lt.b),col="lightgrey",lty=2)
            
            if(pid %in% names(dat1))
              points(x = dat1[match(items.b,dat1$Item.Nr),pid],
                     y = lt.b:1,type="b",col="orange",pch = 15,cex = 1.2)
            if(pid %in% names(dat2))
              points(x = dat2[match(items.b,dat2$Item.Nr),pid],
                     y = lt.b:1,type="b",col="darkred",pch = 18,cex = 1)
            par(xpd=TRUE)
            legend(x=2.5,y = 0.25,bty = "n" ,horiz=T,cex = 0.9,xjust = 0.5,
                   legend = paste0(pid,c(" T1"," T2")),
                   pch=c(15,18),lty=2,col=c("orange","darkred"))
            
          }
          
          
          
        }
        
      }
      
      dev.off()
      
    }
    
    
  }
  
  
  print("Ergebnisse T1 & T2 wurden ausgedruckt und gespeichert")
  

}
